<?php
require 'config.php';
require '2022-07-28-beginners-guide-to-prayer.cfg.php';
require 'templates/blog-header.php';
?>
<p>
Recently a good friend of mine who is taking an interest in Catholicism has
asked me if I could write an article on how to pray. Normally this isn't the
kind of subject I'd want to deal with on my blog, especially since there's
probably millions of people who are better qualified than myself who have
written better articles than anything I could come up with. Nonetheless, I felt
the need to write this article, not only because it was a friend that asked me
to, but also because he has found that many of the articles that exist on the
matter are either too vague or too specific. E.g. a vague article may simply be
several paragraphs of someone essentially saying that praying is having a
conversation with God and growing in communion with Him, while a specific
article will just tell you how to pray a specific devotion. Neither of these are
truly helpful for someone who's just starting out. I remember when I first
started praying it was hard for me to find anything useful on this matter as
well. What beginners need is guidance on <em>what prayer is</em>, and to dive
deeper into <em>how we do it</em>. All this being said, I am still but a layman,
so take what I say with a grain of salt, and continue to expand your prayer life
beyond this article. But I hope to give at least a cursory introduction that
will be useful for beginners.
</p>

<p>
To tackle this subject I'm going to focus on three different sections. The first
will consist of explaining the different <em>modes of prayer</em>, which consist
of manners in which one relates to God. The second is the <em>mediums of prayer</em>
which contemplates the different mediums which we use to engage in the act of
prayer. Thirdly is a section simply to give a few suggested <em>devotions</em>;
by no means an extensive list, but at least to give a starting point.
</p>

<h2>Modes of Prayer</h2>

<p>
When we speak of modes of prayer, we're speaking of distinct and exclusive
manners in which one can relate to God. They are exclusive because your prayer
can only truly be in one mode at any given time. Yet, remembering that these
modes are distinct may help us to keep a balance among all of them in our prayer
life. These modes can be summarized easily with the acronym ACTS: Adoration,
Contrition, Thanksgiving, and Supplication.
</p>

<p>
The first of these would be <em>Adoration</em>, where we contemplate the glory
of God. In effect, we <em>adore</em> Him, for He is the only one worth our
adoration. To be more specific, this is what I've referred to in a previous
article<sup><a href="#r1" >[1]</a></sup> where I explore the true meaning of
adoration. But to summarize it is about giving glory to God and praising Him for
what He is, not for what He does for us.
</p>

<p>
The second, <em>Contrition</em>, consists of recognizing oneself as a sinner,
and asking for the Lord's forgiveness in sincere repentance. We're broken, and
it's necessary to recognize that before God, to bring to Him our weaknesses and
our wounds, that He may heal us. This also will help to inspire humility, for
after having adored Him, we now turn eyes to ourselves and see just how lost we
are without Him.
</p>

<p>
<em>Thanksgiving</em> is the act of giving thanks to the Lord for all He has
done for us, all He is doing, and all He will do. This is necessary, for
although He does so out of love, and there is nothing we can give Him that
doesn't come from Him. This also helps us to realize the important role He plays
in our life and to avoid taking for granted that which He has given us.
</p>

<p>
Finally, the last mode is <em>Supplication</em>, which consists in asking of the
Lord in our favor or that of another. God is not indifferent to us, but loves
each and every one of us as His own son/daughter. When we are in need, we should
go to Him as a child goes to his father for help. A father has no greater joy
than to help his son. So too does God wish to help us, to make us happy. It is
for that reason He calls us to live an eternity with Him in His Kingdom! So too
here on Earth, does He wish for us to be happy - not simply a passing happiness
that comes from temporal things, but a lasting one that can only come from a
profound communion with God.
</p>

<h2>Mediums of Prayer</h2>

<p>
Perhaps <em>medium</em> isn't the correct word to use here, but it's the closest
term I can find to what I'm trying to express. Essentially, when we pray we pray
<em>with or through</em> something. We normally think of praying as something we
say, think, or feel. But ultimately, prayer is about relating to God, which is
something we not only can, but should do with <em>all of our being</em>. This is
not simply some catchy phrase, but truly carries with it a profound meaning. As
human persons we are composed of four things: body, soul, will, and intellect;
and to more fully engage in prayer it is important to use all of these.
</p>

<p>
Going in order, what it means to engage in prayer with our bodies is to
appropriately engage with our material being in the modes of prayer discussed
above. This is commonly understood as using our lips and vocal chords to say
certain phrases, and maybe using our hands and arms to do the Sign of the Cross.
But this is truly a minimal part of it. We can often underestimate just how
important it is to engage with our bodies that which we are trying to express or
experience with our minds; and truly if we reflect our prayer in our bodies this
strengthens the experience. It's not the same to receive Communion standing up
as kneeling, as the latter will put your mind in a state of reception,
submission, and respect. Equally, it is also important to mind the way we dress,
not that we should be extravagant, and calling attention to ourselves - which
would be a lack of humility - but we should give certain places and occasions
their due reverence. To be well dressed for Mass or to go to Adoration
communicates the importance of the event, while if you were to go in your
pajamas then you would likely feel lazy and disconnected. Use your body as a
means of giving glory to God, not by attracting attention to yourself, but by
using it to give due respect and reverence to Him.
</p>

<p>
To pray using one's soul is perhaps a trickier topic, since we should first
agree on what a soul is. I'm not fully qualified to talk about this subject, so
we'll keep things simple and just say that our soul (or <i>anima</i> in Latin)
is our <em>liveliness</em>; it is, in effect, that which <em>animates</em> our
material bodies. This is also a part of us which is particularly damaged with
our sins, causing imperfections to the otherwise perfect creation of God. We
praise God with our souls by caring for it and those of others, and this is
done first and foremost by means of the Sacraments. But this is also done by
configuring our hearts to be more like that of our Lord. To feel what He feels,
to be moved by what moves Him. We do this by bringing to Him all things in our
life and viewing them from God's eyes.
</p>

<p>
To pray with our will is to align our own will to God's. It is an act of trust
in Him, who is good and who loves us, that we must exercise in order to grow in
our prayer life, as it allows us to more clearly hear what He is calling us to,
and be more docile to the Holy Spirit. This is done by accepting that which God
gives us in our lives, be it directly by His divine intervention, or
providentially through others.
</p>

<p>
Finally, to pray with one's intellect requires that we learn about God. What
good is a relationship if we don't know the other person? Can we really say such
a thing is a real relationship, much less one worthy of God? We get to know God
by learning about of Faith, familiarizing ourselves with the Scriptures and our
Tradition, and what the Magisterium has to say about it. By meditating on the
mysteries of Christ and His ministry. Discover who He is. Without this it will
be impossible for you to have any profound or meaningful relationship with Him.
</p>

<h2>Devotions</h2>

<p>
After going over the modes and mediums of prayer we simply lack the
<em>means</em>, which we typically consider to be <em>devotions</em>. These are
common forms of prayer used by many Christians to grow in communion with God. It
is by no means an extensive list, but they are common and very helpful.
</p>

<ol>
	<li>
		<b>The Holy Rosary</b>: The most widespread devotion in the Catholic
		Church, given to us by Our Lady, the Blessed Virgin Mary, through St.
		Dominic. Today the Rosary consists of meditating upon 20 mysteries (15 from
		Our Lady, 5 from St. John Paul II) from Jesus' life and ministry, while
		praying 10 Hail Marys (what's called a decade). You can easily find guides
		online to praying the Rosary along with complimentary prayers between
		decades.
	</li>
	<li>
		<b>Lectio Divina</b>: An old tradition which consists of reading a passage
		from Scripture and reflecting upon it. It consists of four parts: reading,
		meditation, prayer, and contemplation.
	</li>
	<li>
		<b>Liturgy of the Hours</b>: A form of prayer that follows a liturgical
		rubric, similar to that of the Holy Mass. The Liturgy of the Hours focuses
		primarily on the reading of Psalms, and in the antiphony of its central
		prayer it typically utilizes a verse from the Gospel reading of the day in
		the Mass readings. The most common hours to pray are morning (laudes),
		evening (vespers), and night (complete).
	</li>
	<li>
		<b>Worship Music</b>: Not one I'm too fond of, but one that has helped many
		people in their prayer life. Music is a great gift that God has given us, so
		much so that it forms a central part of not only our Earthly Liturgy, but
		even of the Heavenly Liturgy we shall witness in the Beatific Vision (as
		seen in the Book of Revelation). Many find it helpful to guide their prayer,
		and to strengthen it.
	</li>
	<li>
		<b>Divine Mercy Chaplet</b>: Another one I'm not too fond of, but one that
		has started to pick up some popularity in recent years. It's a prayer
		similar to that of the Rosary, but based upon the vision of St. Faustina
		Kowalska, which focuses on God's infinite mercy, asks for the salvation of
		sinners. It's a lot shorter than the Rosary, so it may be a good starting
		point.
	</li>
</ol>

<h2>Some Tips</h2>

Here are some tips for having a good prayer life:

<ol>
	<li>
		Don't be afraid if it is difficult to pray for long periods of time at
		first. Work on perseverance by incrementing the time you pray and the
		intensity of it little by little.
	</li>
	<li>
		Aim to ultimately pray a cumulative hour every day.
	</li>
	<li>
		Be consistent with your prayer schedule and the place you pray. This will
		help your body and soul associate that time &amp; place with prayer, and
		make it easier to enter into a prayerful state.
	</li>
	<li>
		Choose a peaceful place for prayer. Perhaps adorn it with religious images
		that help you to concentrate. In the same way that we are supposed to pray
		with our bodies, this also means that our senses can help us to pray by
		means of incense, candles, icons, etc.
	</li>
	<li>
		Remove all distractions while praying, most especially your phone or any
		other electronic device. If you absolutely require it for prayer then put it
		in airplane mode so as not to receive any notifications; but the ideal is no
		electronics.
	</li>
	<li>
		Pay close attention to the words you say in your prayer, let them resonate
		in your heart, so they may also resonate in your actions.
	</li>
	<li>
		Don't put all of your eggs in one basket. Find a few different prayers to
		pray consistently.
	</li>
	<li>
		Always reserve some time to simply talk to the Lord. A sort of <em>free
		form</em> if you will.
	</li>
	<li>
		Our prayer will always revolve fundamentally around Scripture, so read it
		often. If you're going to pray the Rosary, re-read the different passages
		regarding each of the mysteries with some frequency. Remember that God has a
		message there for you, and His Word is alive and working in you at this
		moment: so listen to what He has to say.
	</li>
	<li>
		If you are more inclined to heavily structured prayer, be sure to pray a
		more flexible form daily. If you are more inclined to the more flexible
		prayers, be sure to pray a more structured one.
	</li>
</ol>

<p>
There's probably a lot more to be said, but this is only a beginner's guide.
Don't get too bogged down by all the text here, just work on it one day at a
time, little by little. I pray this guide will be helpful. And may God bless
you.
</p>

<h2>References</h2>

<ol class="refs" >
	<li id="r1" >
		<a href="/blog/2022-06-07-adoration.html" >
			"Adoration" on The Music in Noise
		</a>
	</li>
</ol>

<?php
require 'templates/blog-footer.php';
?>